@@ -1,4 +1,5 @@
 import numbers
+import warnings
 
 import numpy as np
 from numpy.linalg import LinAlgError
@@ -269,6 +270,11 @@ class PCovR(_BasePCA, LinearModel):
         # should be zero in the case that the features have been properly centered
         self.mean_ = np.mean(X, axis=0)
 
+        if np.max(np.abs(self.mean_)) > self.tol:
+            warnings.warn(
+                "This class does not automatically center data, and your data mean is greater than the supplied tolerance."
+            )
+
         if self.space is not None and self.space not in [
             "feature",
             "sample",
@@ -610,7 +616,13 @@ class PCovR(_BasePCA, LinearModel):
         X_original ndarray, shape (n_samples, n_features)
         """
 
-        return T @ self.ptx_ + self.mean_
+        if np.max(np.abs(self.mean_)) > self.tol:
+            warnings.warn(
+                "This class does not automatically un-center data, and your data mean is greater than the supplied tolerance,"
+                "so the inverse transformation will be off by the original data mean."
+            )
+
+        return T @ self.ptx_
 
     def predict(self, X=None, T=None):
         """Predicts the property values using regression on X or T"""
