@@ -20,11 +20,13 @@ def pointwise_global_reconstruction_error(
     scaler=None,
     estimator=None,
 ):
-    """Computes the pointwise global reconstruction error using the source X
+    r"""Computes the pointwise global reconstruction error using the source X
     to reconstruct the features or samples of target Y based on a minimization
     by linear regression:
 
-    :math:`GRE^{(i)}(X,Y) = \min_W ||y_i - x_iW||` % # noqa: W605
+    .. math::
+
+        GRE^{(i)}(X,Y) = \min_W ||y_i - x_iW||
 
     If used with X and Y of shape (n_samples, n_features) it computes the pointwise
     global reconstruction error of the features as defined in Ref. [Goscinski2021]_.
@@ -109,11 +111,13 @@ def global_reconstruction_error(
     scaler=None,
     estimator=None,
 ):
-    """Computes the global reconstruction error using the source X
+    r"""Computes the global reconstruction error using the source X
     to reconstruct the features or samples of target Y based on a minimization
     by linear regression:
 
-    :math:`GRE(X,Y) = \min_W ||Y - XW||`` % # noqa: W605
+    .. math::
+
+        GRE(X,Y) = \min_W ||Y - XW||
 
     If used with X and Y of shape (n_samples, n_features) it computes the
     global reconstruction error of the features as defined in Ref. [Goscinski2021]_.
@@ -186,11 +190,13 @@ def pointwise_global_reconstruction_distortion(
     scaler=None,
     estimator=None,
 ):
-    """Computes the pointwise global reconstruction distortion using the source X
+    r"""Computes the pointwise global reconstruction distortion using the source X
     to reconstruct the features or samples of target Y based on a minimization
     by orthogonal regression:
 
-    :math:`GRD^{(i)}(X,Y) = \min_Q ||y_i - x_iQ\|| \quad\mathrm{subject\ to}\quad Q^TQ=I` % # noqa: W605
+    .. math::
+
+        GRD^{(i)}(X,Y) = \min_Q ||y_i - x_iQ\|| \quad\mathrm{subject\ to}\quad Q^TQ=I
 
     If used with X and Y of shape (n_samples, n_features) it computes the pointwise
     global reconstruction distortion of the features as defined in Ref. [Goscinski2021]_.
@@ -280,11 +286,13 @@ def global_reconstruction_distortion(
     scaler=None,
     estimator=None,
 ):
-    """Computes the global reconstruction distortion using the source X
+    r"""Computes the global reconstruction distortion using the source X
     to reconstruct the features or samples of target Y based on a minimization
     by orthogonal regression:
 
-    :math:`GRD(X,Y) = \min_Q ||y - XQ\|| \quad\mathrm{subject\ to}\quad Q^TQ=I` % # noqa: W605
+    .. math::
+
+        GRD(X,Y) = \min_Q ||y - XQ\|| \quad\mathrm{subject\ to}\quad Q^TQ=I
 
     If used with X and Y of shape (n_samples, n_features) it computes the
     global reconstruction distortion of the features as defined in Ref. [Goscinski2021]_.
@@ -363,8 +371,14 @@ def pointwise_local_reconstruction_error(
     to reconstruct the features or samples of target Y based on a minimization
     by linear regression:
 
-    :math:`\tilde{\mathbf{x}}'_i = \bar{\mathbf{x}} + (\mathbf{x}_i - \bar{\mathbf{x}})\mathbf{P}^{(i)}` % # noqa: W605
-    :math:`LRE^{(i)}(X,Y) = \|\mathbf{x}'_i - \tilde{\mathbf{x}}'_i\|^2` % # noqa: W605
+    .. math::
+
+        \tilde{\mathbf{x}}'_i = \bar{\mathbf{x}} + (\mathbf{x}_i
+                                - \bar{\mathbf{x}})\mathbf{P}^{(i)}
+
+    .. math::
+
+        LRE^{(i)}(X,Y) = \|\mathbf{x}'_i - \tilde{\mathbf{x}}'_i\|^2
 
     If used with X and Y of shape (n_samples, n_features) it computes the pointwise
     local reconstruction error of the features as defined in Ref. [Goscinski2021]_.
@@ -493,7 +507,9 @@ def local_reconstruction_error(
     to reconstruct the features or samples of target Y based on a minimization
     by linear regression:
 
-    :math:`LRE(X,Y) = \sqrt{\sum_i LRE^{(i)}(X,Y)}/\sqrt{n_\text{test}}` % # noqa: W605
+    .. math::
+
+        LRE(X,Y) = \sqrt{\sum_i LRE^{(i)}(X,Y)}/\sqrt{n_\text{test}}
 
     If used with X and Y of shape (n_samples, n_features) it computes the
     local reconstruction error of the features as defined in Ref. [Goscinski2021]_.
